==> scala-k8s-objects_sjs1_2.13-0.16.1-sources.jar: io/k8s/apiextensions-apiserver/pkg/apis/apiextensions/v1/ExternalDocumentation.scala <==
package io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1

import dev.hnaderi.k8s.utils._

/** ExternalDocumentation allows referencing an external resource for extended documentation. */
final case class ExternalDocumentation(
  description : Option[String] = None,
  url : Option[String] = None
) {

  /** Returns a new data with description set to new value */
  def withDescription(value: String) : ExternalDocumentation = copy(description = Some(value))
  /** if description has a value, transforms to the result of function*/
  def mapDescription(f: String => String) : ExternalDocumentation = copy(description = description.map(f))

  /** Returns a new data with url set to new value */
  def withUrl(value: String) : ExternalDocumentation = copy(url = Some(value))
  /** if url has a value, transforms to the result of function*/
  def mapUrl(f: String => String) : ExternalDocumentation = copy(url = url.map(f))
}

object ExternalDocumentation {

    implicit val encoder : Encoder[io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.ExternalDocumentation] = new Encoder[io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.ExternalDocumentation] {
        def apply[T : Builder](o: io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.ExternalDocumentation) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("description", o.description)
            .write("url", o.url)
            .build
        }
    }

    implicit val decoder: Decoder[ExternalDocumentation] = new Decoder[ExternalDocumentation] {
      def apply[T : Reader](t: T): Either[String, ExternalDocumentation] = for {
          obj <- ObjectReader(t)
          description <- obj.readOpt[String]("description")
          url <- obj.readOpt[String]("url")
      } yield ExternalDocumentation (
          description = description,
          url = url
        )
    }
}

==> scala-k8s-objects_sjs1_3-0.3.0-sources.jar: io/k8s/apiextensions-apiserver/pkg/apis/apiextensions/v1/ExternalDocumentation.scala <==
package io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1

import dev.hnaderi.k8s.utils._

/** ExternalDocumentation allows referencing an external resource for extended documentation. */
final case class ExternalDocumentation(
  description : Option[String] = None,
  url : Option[String] = None
) {

  /** Returns a new data with description set to new value */
  def withDescription(value: String) : ExternalDocumentation = copy(description = Some(value))
  /** if description has a value, transforms to the result of function*/
  def mapDescription(f: String => String) : ExternalDocumentation = copy(description = description.map(f))

  /** Returns a new data with url set to new value */
  def withUrl(value: String) : ExternalDocumentation = copy(url = Some(value))
  /** if url has a value, transforms to the result of function*/
  def mapUrl(f: String => String) : ExternalDocumentation = copy(url = url.map(f))
}

object ExternalDocumentation {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.ExternalDocumentation, T] = new Encoder[io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.ExternalDocumentation, T] {
        def apply(o: io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.ExternalDocumentation) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("description", o.description)
            .write("url", o.url)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, ExternalDocumentation] = new Decoder[T, ExternalDocumentation] {
      def apply(t: T): Either[String, ExternalDocumentation] = for {
          obj <- ObjectReader(t)
          description <- obj.readOpt[String]("description")
          url <- obj.readOpt[String]("url")
      } yield ExternalDocumentation (
          description = description,
          url = url
        )
    }
}
